ANSYS MAPDL 
===========

>**[ANSYS
Multiphysics](http://www.ansys.com/Products/Simulation+Technology/Structural+Mechanics/ANSYS+Multiphysics)**
software offers a comprehensive product solution for both multiphysics
and single-physics analysis. The product includes structural, thermal,
fluid and both high- and low-frequency electromagnetic analysis. The
product also contains solutions for both direct and sequentially coupled
physics problems including direct coupled-field elements and the ANSYS
multi-field solver.

>To run ANSYS MAPDL in batch mode you can utilize/modify the
default mapdl.pbs script and execute it via the qsub command.

  #!/bin/bash
  #PBS -l nodes=2:ppn=24
  #PBS -q qprod
  #PBS -N ANSYS-Project
  #PBS -A OPEN-0-0

  #! Mail to user when job terminate or abort
  #PBS -m ae

  #!change the working directory (default is home directory)
  #cd <working directory> (working directory must exists)
  WORK_DIR="/scratch/work/user/$USER"
  cd $WORK_DIR

  echo Running on host `hostname`
  echo Time is `date`
  echo Directory is `pwd`
  echo This jobs runs on the following processors:
  echo `cat $PBS_NODEFILE`

  module load ANSYS/16.1

  #### Set number of processors per host listing
  procs_per_host=24
  #### Create host list
  hl=""
  for host in `cat $PBS_NODEFILE`
  do
   if [ "$hl" = "" ]
   then hl="$host:$procs_per_host"
   else hl="$:$host:$procs_per_host"
   fi
  done

  echo Machines: $hl

  # prevent ANSYS from attempting to use scif0 interface
  export MPI_IC_ORDER="UDAPL"

  #-i input.dat includes the input of analysis in APDL format
  #-o file.out is output file from ansys where all text outputs will be redirected 
  #-p the name of license feature (aa_r=ANSYS Academic Research, ane3fl=Multiphysics(commercial), aa_r_dy=Academic AUTODYN)
  ansys161 -b -dis -usessh -p aa_r -i input.dat -o file.out -machines "$hl" -dir $WORK_DIR

Header of the PBS file (above) is common and description can be find on
[this
site](../../resource-allocation-and-job-execution/job-submission-and-execution.html).
[SVS FEM](http://www.svsfem.cz) recommends to utilize
sources by keywords: nodes, ppn. These keywords allows to address
directly the number of nodes (computers) and cores (ppn) which will be
utilized in the job. Also the rest of code assumes such structure of
allocated resources.

Working directory has to be created before sending pbs job into the
queue. Input file should be in working directory or full path to input
file has to be specified. Input file has to be defined by common APDL
file which is attached to the ansys solver via parameter -i

License** should be selected by parameter -p. Licensed products are
the following: aa_r (ANSYS **Academic** Research), ane3fl (ANSYS
Multiphysics)-**Commercial**, aa_r_dy (ANSYS **Academic**
AUTODYN)>
[More about licensing here](licensing.html)




